
/*****************************************************************************
**
** File:        mqwrapcommit.c
** Purpose:     Natural Interface for MQSeries
** Description: MQCMIT function
**
** (c) Copyright 2000 by IBM
**
*****************************************************************************/

#include <stdio.h>
#include <stdlib.h>             /* Memory and type conversions */
#include <string.h>             /* strcpy stuff */
#include <ctype.h>              /* is upper stuff */
#include <time.h>               /* time of course */
#include <errno.h>              /* contains errno , last error indicator */
#include <fcntl.h>              /* FILE I/O related protos and defines */
#include <limits.h>		/* FILE I/O related protos and defines */
#include <io.h>             /* defines for file access              */
#include <sys/types.h>          /* for data types sycj as time          */
#include <sys/stat.h>           /* finding out status info              */

#include "cmqc.h"		        /* MQ Headers		*/
#include "natuser.h"	    	/* Natural User Exit	*/
#include "namq.h"               /* MQ interface function prototypes */

static FILE *dbgfile = NULL;

NATFCT NAMQCMIT NATARGDEF(nparm, parmptr, parmdec)
{
#ifdef MQCMIT_DEBUG
  static char * func = "NAMQCMIT : "	;
#endif

  MQHCONN	con_hndl	;
  MQBO   	begin_options	;
  MQLONG 	cc		;
  MQLONG 	rc 		;

#ifdef MQCMIT_DEBUG
   dbgfile = dbgopen();
#endif
  /*
  ** test number of arguments
  */
  if (nparm != 3) {
#ifdef MQCMIT_DEBUG
  if (dbgfile != NULL) {
    fprintf(dbgfile, "\n%s Wrong number of parameters: %d" ,func, nparm) ;
	dbgclose();
  }
#endif
		return 1;
  	 }


  /*
  ** move Con hndl from Natural to Local variable
  */

  memmove ((char *) &con_hndl, (char *) parmptr[0], sizeof(MQHCONN));

  /*
  ** Call the commit routine
  */

  mq_cmit ( con_hndl, &cc, &rc);

#ifdef MQCMIT_DEBUG
  if (dbgfile != NULL) {
    fprintf(dbgfile, "\n\n%s handle = %d cc = %d , rc = %d ", func , con_hndl , cc , rc ) ;
  }
#endif

  /*
  ** move Condition Code to Natural Return block
  */

  memmove ((char *) parmptr[1], (char *) &cc, sizeof(MQLONG));

  /*
  ** move Return Code to Natural Return block
  */

  memmove ((char *) parmptr[2], (char *) &rc, sizeof(MQLONG));

#ifdef MQCMIT_DEBUG
  if (dbgfile != NULL) {
    dbgclose() ;
  }
#endif

  return 0;

} /* MQCMIT */




/*
***********************************************************************
			mq_cmit
***********************************************************************
*/

void mq_cmit (MQHCONN con_hndl, MQLONG *cc, MQLONG *rc)
{
#ifdef MQCMIT_DEBUG
  static char * func = "mq_cmit : "	;
#endif

    MQCMIT(con_hndl, cc , rc) ;

#ifdef MQCMIT_DEBUG
    if ( *cc == MQCC_FAILED) {
  		if (dbgfile != NULL) {
		  	fprintf(dbgfile, "%s Failed to commit a transaction\n",func);
		}
	}
#endif

    return ;

}


