
/*****************************************************************************
**
** File:        mqwrapopen.c
** Purpose:     Natural Interface for MQSeries
** Description: MQOPEN function
**
** (c) Copyright 2000 by IBM
**
*****************************************************************************/

#include <stdio.h>
#include <stdlib.h>             /* Memory and type conversions */
#include <string.h>             /* strcpy stuff */
#include <ctype.h>              /* is upper stuff */
#include <time.h>               /* time of course */
#include <errno.h>              /* contains errno , last error indicator */
#include <fcntl.h>              /* FILE I/O related protos and defines */
#include <limits.h>		/* FILE I/O related protos and defines */
#include <io.h>             /* defines for file access              */
#include <sys/types.h>          /* for data types sycj as time          */
#include <sys/stat.h>           /* finding out status info              */

#include "cmqc.h"		        /* MQ Headers		*/
#include "natuser.h"	    	/* Natural User Exit	*/
#include "namq.h"               /* MQ interface function prototypes */

static FILE *dbgfile = NULL;

NATFCT NAMQOPEN NATARGDEF(nparm, parmptr, parmdec)
{
#ifdef MQOPEN_DEBUG
  static char * func = "NAMQOPEN : "	;
  char dbgdata[100];
#endif

  MQHCONN	con_hndl	;
  MQOD          obj_desc = {MQOD_DEFAULT} ;
  MQLONG 	options 	;
  MQHOBJ        obj_hndl        ;
  MQLONG 	cc		;
  MQLONG 	rc 		;

#ifdef MQOPEN_DEBUG
   dbgfile = dbgopen();
#endif

  /*
  ** test number of arguments
  */

  cc = MQCC_FAILED ;
  rc = MQCC_FAILED ;

  /*
  ** move Condition Code to Natural Return block
  */

  memmove ((char *) parmptr[4], (char *) &cc, sizeof(MQLONG));

  /*
  ** move Return Code to Natural Return block
  */

  memmove ((char *) parmptr[5], (char *) &rc, sizeof(MQLONG));


  if (nparm != 6 )
       {
#ifdef MQOPEN_DEBUG
		if (dbgfile != NULL) {
    		fprintf(dbgfile, "\n%s Wrong number of Parameters! got '%d'\n" ,func,
                                        nparm) ;
			dbgclose();
	    }
#endif
		rc = 1 ;

  		/*
  		** move Return Code to Natural Return block
  		*/

	  	memmove ((char *) parmptr[5], (char *) &rc, sizeof(MQLONG));

		return 1;
  	 }

  /*
  ** move Con Handle from Natural to Local variable
  */

  memmove ((char *) &con_hndl, (char *) parmptr[0], sizeof(MQHCONN));

#ifdef MQOPEN_DEBUG
  if (dbgfile != NULL) {
    fprintf(dbgfile, "\n\n%s con handle: %d", func , con_hndl ) ;
  }
#endif

  /*
  ** move Object Descriptor from Natural to Local variable
  */

  memmove ((char *) &obj_desc, (char *) parmptr[1], sizeof(MQOD));

#ifdef MQOPEN_DEBUG
  if (dbgfile != NULL) {
	dbgtrunc(dbgdata, obj_desc.StrucId, 4, 4);
    fprintf(dbgfile, "\n%s Object Descriptor:\n Structure ID: '%s'", func , dbgdata) ;
    fprintf(dbgfile, "\n Version: %d", obj_desc.Version);
    fprintf(dbgfile, "\n Object Type : %d", obj_desc.ObjectType);
	dbgtrunc(dbgdata, obj_desc.ObjectName, 48, 0);
    fprintf(dbgfile, "\n Object Name: '%s'", dbgdata) ;
	dbgtrunc(dbgdata, obj_desc.ObjectQMgrName, 48, 0);
    fprintf(dbgfile, "\n Q Manager Name: '%s'", dbgdata) ;
	dbgtrunc(dbgdata, obj_desc.DynamicQName, 48, 0);
    fprintf(dbgfile, "\n Dynamic Q Name: '%s'", dbgdata) ;
  }
#endif

  /*
  ** move Options from Natural to Local variable
  */

  memmove ((char *) &options, (char *) parmptr[2], sizeof(MQLONG));

#ifdef MQOPEN_DEBUG
  if (dbgfile != NULL) {
    fprintf(dbgfile, "\n%s options: %d", func , options ) ;
  }
#endif

  /*
  ** Call the Open routine
  */

  mq_open ( con_hndl, &obj_desc, options, &obj_hndl, &cc, &rc);

#ifdef MQOPEN_DEBUG
  if (dbgfile != NULL) {
    fprintf(dbgfile, "\n%s handle = %d cc = %d , rc = %d ", func , obj_hndl , cc , rc ) ;
  }
#endif

  /*
  ** move Handle to Natural Return block
  */

  memmove ((char *) parmptr[3], (char *) &obj_hndl, sizeof(MQHOBJ));

  /*
  ** move Condition Code to Natural Return block
  */

  memmove ((char *) parmptr[4], (char *) &cc, sizeof(MQLONG));

  /*
  ** move Return Code to Natural Return block
  */

  memmove ((char *) parmptr[5], (char *) &rc, sizeof(MQLONG));

#ifdef MQOPEN_DEBUG
  if (dbgfile != NULL) {
    dbgclose() ;
  }
#endif

  return 0;

} /* MQOPEN */


/*
***********************************************************************
			mq_open
***********************************************************************
*/

void mq_open (MQHCONN con_hndl, MQOD * obj_desc, MQLONG options,
                       MQHOBJ * obj_hndl, MQLONG *cc, MQLONG *rc)
{
#ifdef MQOPEN_DEBUG
  static char * func = "mq_open : "	;
#endif

    MQOPEN(con_hndl, obj_desc, options, obj_hndl, cc , rc) ;

#ifdef MQOPEN_DEBUG
    if ( *cc == MQCC_FAILED) {
       if (dbgfile != NULL) {
	     fprintf(dbgfile, "%s Failed to Open, rc = %d\n", func, *rc);
	   }
	}
#endif

    return ;

}


